@@ -14,3 +14,14 @@ class EsdtTransfer:
     token_identifier: str
     amount: int
     nonce: int = 0
+
+
+@dataclass
+class OnChainTransfer:
+    """
+    Represent any type of token transfer on chain
+    """
+    sender: str
+    receiver: str
+    token: str
+    amount: str
